@@ -12,6 +12,7 @@ import pickle as pkl
 from types import FunctionType
 from typing import (Optional, ByteString, Union, Callable, Dict, Any, List,
                     Tuple)
+from functools import partial
 from collections import OrderedDict
 from warnings import warn
 
@@ -748,15 +749,18 @@ class BaseEnvironnement(BaseEstimator):
             torch.set_num_threads(torch.get_num_threads())
 
         if not state:
+            if isinstance(loss_fn, FunctionType):
+                loss_name = loss_fn.__name__
+            elif isinstance(loss_fn, partial):
+                loss_name = loss_fn.func.__name__
+            else:
+                loss_name = loss_fn.__class__.__name__
             state = FitState(
                 id_process=id_processes,
                 nb_epoch=nb_epoch,
                 epoch_max_steps=len(dataset),
                 eval_max_steps=len(eval_dataset) if eval_dataset else 0,
-                loss_name=(
-                    loss_fn.__name__ if isinstance(loss_fn, FunctionType)
-                    else loss_fn.__class__.__name__
-                ),
+                loss_name=loss_name,
                 n_iter=0
             )
         if not control:
@@ -779,6 +783,12 @@ class BaseEnvironnement(BaseEstimator):
         self.to(control.device)
         if control.device.type != "tpu" and hasattr(self, 'post_move_to_tup'):
             self.post_move_to_tup()
+        if isinstance(loss_fn, FunctionType):
+            co_varnames = loss_fn.__code__.co_varnames
+        elif isinstance(loss_fn, partial):
+            co_varnames = loss_fn.func.__code__.co_varnames
+        else:
+            co_varnames = loss_fn.__class__.forward.__code__.co_varnames
         state_in_loss = list(
             filter(
                 lambda x: 
@@ -787,22 +797,11 @@ class BaseEnvironnement(BaseEstimator):
                         x.lower() == 'fitstate' or
                         x.lower() == 'fit_state'
                     ),
-                (
-                    loss_fn.__code__.co_varnames
-                    if isinstance(loss_fn, FunctionType)
-                    else loss_fn.__class__.forward.__code__.co_varnames
-                )
+                co_varnames
             )
         )
         state_in_loss_kargs = list(
-            filter(
-                lambda x: x == 'kargs' or x == 'kwargs',
-                (
-                    loss_fn.__code__.co_varnames
-                    if isinstance(loss_fn, FunctionType)
-                    else loss_fn.__class__.forward.__code__.co_varnames
-                )
-            )
+            filter(lambda x: x == 'kargs' or x == 'kwargs', co_varnames)
         )
         if len(state_in_loss) == 1:
             loss_kargs[state_in_loss[0]] = state
